
Welcome to shoebill's documentation!
===========================================

Contents:

.. toctree::
   :maxdepth: 2

.. automodule:: shoebill
    :members:
    :inherited-members:
    :undoc-members:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

